@@ -10,7 +10,7 @@
 #include <QDir>
 #include <QRegularExpression>
 #include <QStandardPaths>
-// // // // // // //
+
 #include <KLocalizedString>
 
 const char s_colourCodes[] = "\u001B[[0-9]*m";
@@ -50,7 +50,7 @@ bool DifferentialRevision::buildArcCommand(const QString &workDir, const QString
             m_arcInput = patchFile;
         }
         m_arcCmd.setWorkingDirectory(workDir);
-        connect(&m_arcCmd, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, &DifferentialRevision::done);
+        connect(&m_arcCmd, &QProcess::finished, this, &DifferentialRevision::done);
         setPercent(33);
         ret = true;
     } else {
@@ -186,7 +186,7 @@ bool Phabricator::DiffRevList::buildArcCommand(const QString &workDir, const QSt
         m_arcCmd.setProgram(arc);
         m_arcCmd.setArguments(args);
         m_arcCmd.setWorkingDirectory(workDir);
-        connect(&m_arcCmd, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, &DiffRevList::done);
+        connect(&m_arcCmd, &QProcess::finished, this, &DiffRevList::done);
         setPercent(33);
         ret = true;
     } else {
